@@ -435,6 +435,7 @@ class MixIn (
         'mounted_or_reloaded': 6
     }
     def life_cycle (self, phase, obj):
+        self.bus.emit (phase)
         if phase in ("umounted", "before_reload"):
             self.umount_all ()
         index = self.PHASES.get (phase)
@@ -480,15 +481,11 @@ class MixIn (
             self.basepath = route
 
     def start (self, wasc, route):
-        self.bus.emit ("app:starting", wasc)
         self._start (wasc, route)
-        self.bus.emit ("app:started", wasc)
         self._started = True
 
     def restart (self, wasc, route):
         self._reloading = True
-        self.bus.emit ("app:restarting", wasc)
         self._start (wasc, route, True)
-        self.bus.emit ("app:restarted", wasc)
         self._reloading = False
 
