@@ -281,17 +281,22 @@ class WAS (wsgiappservice.WAS):
             kargs ['args'] = (_was,) + kargs.get ('args', ())
         return _was, args, kargs
 
-    def ThreadFuture (self, target, *args, **kargs):
+    def Pass (self, target, *args, **kargs):
         _was, args, kargs = self._insert_cloned_was (args, kargs)
         return self.executors.create_thread (_was.ID, target, *args, **kargs).then ()
+    ThreadFuture = Pass
 
     def File (self, *args, **karg):
         return self.response.File (*args, **karg)
 
     def Static (self, uri):
-        if not uri.startswith ('/'):
-            uri = self.static (uri)
-        return self.response.Static (uri)
+        return self.Mounted (self.static (uri))
+
+    def Media (self, uri):
+        return self.Mounted (self.media (uri))
+
+    def Mounted (self, uri):
+        return self.response.Mounted (uri)
 
     def ProxyPass (self, alias, path, timeout = 3):
         def respond (was, rs):
